NAME

Zuzu::Lexer - lexer that tokenizes ZuzuScript source text

DESCRIPTION

Scans normalized source text and emits Zuzu::Token objects with source location metadata.

INHERITANCE

Inherits from Moo::Object.

ROLES

None.

ATTRIBUTES

src

Type: Str.

Unicode-normalized source text being lexed.

filename

Type: Maybe[Str].

Filename attached to generated tokens and parser errors.

pos

Type: Int.

Current character offset in src.

line

Type: Int.

1-based source line number used for diagnostics.

col

Type: Int.

1-based source column number used for diagnostics.

METHODS

new

Constructs and returns a new instance of this class.

next_token

Consumes input and returns the next Zuzu::Token.

SEE ALSO

Subclasses: none in this distribution.

COPYRIGHT AND LICENCE

Zuzu::Lexer is copyright Toby Inkster.

It is free software; you may redistribute it and/or modify it under the terms of either the Artistic License 1.0 or the GNU General Public License version 2.